# PyOptimum

This is a library to facilitate access to the 
[Optimize API](https://optimize.vicbee.net/optimize/api/ui) and [Models API](https://optimize.vicbee.net/models/api/ui) in Python.

## Installation

Install with pip by typing:

    pip install pyoptimum

## Documentation

Documentation is available at [read the docs](https://pyoptimum.readthedocs.io).

See [VICBee](https://vicbee.net) for more details.
